package com.ruoyi.hezhi.mapper;

import com.ruoyi.hezhi.domain.TbCourseChapter;

import java.util.List;
import java.util.Map;

/**
 * 课程章节Mapper接口
 *
 * @author ruoyi
 * @date 2024-09-14
 */
public interface TbCourseChapterMapper
{
    /**
     * 查询课程章节
     *
     * @param chapterId 课程章节主键
     * @return 课程章节
     */
    public TbCourseChapter selectTbCourseChapterByChapterId(Long chapterId);

    /**
     * 查询课程章节列表
     *
     * @param tbCourseChapter 课程章节
     * @return 课程章节集合
     */
    public List<TbCourseChapter> selectTbCourseChapterList(TbCourseChapter tbCourseChapter);

    /**
     * 新增课程章节
     *
     * @param tbCourseChapter 课程章节
     * @return 结果
     */
    public int insertTbCourseChapter(TbCourseChapter tbCourseChapter);

    /**
     * 修改课程章节
     *
     * @param tbCourseChapter 课程章节
     * @return 结果
     */
    public int updateTbCourseChapter(TbCourseChapter tbCourseChapter);

    /**
     * 删除课程章节
     *
     * @param chapterId 课程章节主键
     * @return 结果
     */
    public int deleteTbCourseChapterByChapterId(Long chapterId);

    /**
     * 批量删除课程章节
     *
     * @param chapterIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbCourseChapterByChapterIds(Long[] chapterIds);


    /**
     * 视频列表
     *
     * @param params 参数
     * @return ok
     */
    public List<Map<String, Object>> getCourseChapterList(Map<String, Object> params);
}
